==> cscec5b-rmat-impl-3.0.1-20241109.065542-320-sources.jar: com/ejianc/business/rmat/vo/ReportCorpPcVO.java <==
package com.ejianc.business.rmat.vo;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 日租金
 *
 * @author generator
 *
 */
public class ReportCorpPcVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long materialTypeId; // 物资分类id
    private String materialTypeName; // 物资分类名称
    private Long rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private BigDecimal damageMny; // 赔偿金额
    private BigDecimal damageNum; // 报损数量
    private BigDecimal damagePrice; // 报损单价

    private List<ReportCorpPcDetailVO> linkList = new ArrayList<>();

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(Long rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getDamageMny() {
        return damageMny;
    }

    public void setDamageMny(BigDecimal damageMny) {
        this.damageMny = damageMny;
    }

    public BigDecimal getDamageNum() {
        return damageNum;
    }

    public void setDamageNum(BigDecimal damageNum) {
        this.damageNum = damageNum;
    }

    public BigDecimal getDamagePrice() {
        return damagePrice;
    }

    public void setDamagePrice(BigDecimal damagePrice) {
        this.damagePrice = damagePrice;
    }

    public List<ReportCorpPcDetailVO> getLinkList() {
        return linkList;
    }

    public void setLinkList(List<ReportCorpPcDetailVO> linkList) {
        this.linkList = linkList;
    }
}

==> cscec5b-rmat-impl-3.0.1-20250120.095631-338-sources.jar: com/ejianc/business/rmat/vo/ReportCorpPcVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 日租金
 *
 * @author generator
 *
 */
public class ReportCorpPcVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long materialTypeId; // 物资分类id
    private String materialTypeName; // 物资分类名称
    private Long rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private BigDecimal damageMny; // 赔偿金额
    private BigDecimal damageNum; // 报损数量
    private BigDecimal damagePrice; // 报损单价
    private BigDecimal rentPrice; // 租赁单价

    private List<ReportCorpPcDetailVO> linkList = new ArrayList<>();

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(Long rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getDamageMny() {
        return damageMny;
    }

    public void setDamageMny(BigDecimal damageMny) {
        this.damageMny = damageMny;
    }

    public BigDecimal getDamageNum() {
        return damageNum;
    }

    public void setDamageNum(BigDecimal damageNum) {
        this.damageNum = damageNum;
    }

    public BigDecimal getDamagePrice() {
        return damagePrice;
    }

    public void setDamagePrice(BigDecimal damagePrice) {
        this.damagePrice = damagePrice;
    }

    public BigDecimal getRentPrice() {
        return rentPrice;
    }

    public void setRentPrice(BigDecimal rentPrice) {
        this.rentPrice = rentPrice;
    }

    public List<ReportCorpPcDetailVO> getLinkList() {
        return linkList;
    }

    public void setLinkList(List<ReportCorpPcDetailVO> linkList) {
        this.linkList = linkList;
    }
}
